searchData={"items":[{"type":"module","title":"BeamFile","doc":"An interface to the BEAM file format.\n\nThis module is mainly a wrapper around Erlangs `:beam_lib`.\n\nFor more information see the Erlang documentation for the module\n[`beam_lib`](https://www.erlang.org/doc/man/beam_lib.html)\n\nFurthermore, different code representations can be generated from the file.\n- `BeamFile.abstract_code/1`\n- `BeamFile.byte_code/1`\n- `BeamFile.erl_code/1`\n- `BeamFile.elixir_code/2`\n- `BeamFile.elixir_quoted/1`\n\nTo use the functions above with a module name the module must be compiled\nand loaded. The functions can also be used with the binary of a module.","ref":"BeamFile.html"},{"type":"function","title":"BeamFile.abstract_code/1","doc":"Returns the `:abstract_code` chunk.","ref":"BeamFile.html#abstract_code/1"},{"type":"function","title":"Examples - BeamFile.abstract_code/1","doc":"iex> BeamFile.abstract_code(BeamFile.Example)\n    {\n      :ok,\n      [\n        {:attribute, 1, :file, {'test/fixtures/example.ex', 1}},\n        {:attribute, 1, :module, BeamFile.Example},\n        {:attribute, 1, :compile, [:no_auto_import]},\n        {:attribute, 1, :export, [__info__: 1, hello: 0]},\n        {\n          :attribute,\n          1,\n          :spec,\n          {\n            {:__info__, 1},\n            [\n              {\n                :type,\n                1,\n                :fun,\n                [\n                  {\n                    :type,\n                    1,\n                    :product,\n                    [\n                      {\n                        :type,\n                        1,\n                        :union,\n                        [\n                          {:atom, 1, :attributes},\n                          {:atom, 1, :compile},\n                          {:atom, 1, :functions},\n                          {:atom, 1, :macros},\n                          {:atom, 1, :md5},\n                          {:atom, 1, :exports_md5},\n                          {:atom, 1, :module},\n                          {:atom, 1, :deprecated},\n                          {:atom, 1, :struct}\n                        ]\n                      }\n                    ]\n                  },\n                  {:type, 1, :any, []}\n                ]\n              }\n            ]\n          }\n        },\n        {\n          :function,\n          0,\n          :__info__,\n          1,\n          [\n            {:clause, 0, [{:atom, 0, :module}], [], [{:atom, 0, BeamFile.Example}]},\n            {\n              :clause,\n              0,\n              [{:atom, 0, :functions}],\n              [],\n              [{:cons, 0, {:tuple, 0, [{:atom, 0, :hello}, {:integer, 0, 0}]}, {nil, 0}}]\n            },\n            {:clause, 0, [{:atom, 0, :macros}], [], [nil: 0]},\n            {:clause, 0, [{:atom, 0, :struct}], [], [{:atom, 0, nil}]},\n            {\n              :clause,\n              0,\n              [{:atom, 0, :exports_md5}],\n              [],\n              [\n                {\n                  :bin,\n                  0,\n                  [\n                    {\n                      :bin_element,\n                      0,\n                      {:string, 0,\n                        [166, 117, 1, 22, 146, 56, 30, 199, 203, 141, 158, 223, 3, 11, 225, 190]},\n                      :default,\n                      :default\n                    }\n                  ]\n                }\n              ]\n            },\n            {\n              :clause,\n              0,\n              [{:match, 0, {:var, 0, :Key}, {:atom, 0, :attributes}}],\n              [],\n              [\n                {\n                  :call,\n                  0,\n                  {:remote, 0, {:atom, 0, :erlang}, {:atom, 0, :get_module_info}},\n                  [{:atom, 0, BeamFile.Example}, {:var, 0, :Key}]\n                }\n              ]\n            },\n            {\n              :clause,\n              0,\n              [{:match, 0, {:var, 0, :Key}, {:atom, 0, :compile}}],\n              [],\n              [\n                {\n                  :call,\n                  0,\n                  {:remote, 0, {:atom, 0, :erlang}, {:atom, 0, :get_module_info}},\n                  [{:atom, 0, BeamFile.Example}, {:var, 0, :Key}]\n                }\n              ]\n            },\n            {\n              :clause,\n              0,\n              [{:match, 0, {:var, 0, :Key}, {:atom, 0, :md5}}],\n              [],\n              [\n                {\n                  :call,\n                  0,\n                  {:remote, 0, {:atom, 0, :erlang}, {:atom, 0, :get_module_info}},\n                  [{:atom, 0, BeamFile.Example}, {:var, 0, :Key}]\n                }\n              ]\n            },\n            {:clause, 0, [{:atom, 0, :deprecated}], [], [nil: 0]}\n          ]\n        },\n        {:function, 2, :hello, 0, [{:clause, 2, [], [], [{:atom, 2, :world}]}]}\n      ]\n    }","ref":"BeamFile.html#abstract_code/1-examples"},{"type":"function","title":"BeamFile.abstract_code!/1","doc":"Same as `abstract_code/1` but raises `BeamFile.Error`","ref":"BeamFile.html#abstract_code!/1"},{"type":"function","title":"BeamFile.all_chunks/2","doc":"Returns chunk data for all chunks.\n\nThe `type` argument forces the use of `:ids` or `:names`, defaults to `:names`.","ref":"BeamFile.html#all_chunks/2"},{"type":"function","title":"Examples - BeamFile.all_chunks/2","doc":"iex> {:ok, chunks} = BeamFile.all_chunks(BeamFile.Example, :names)\n    iex> chunks |> Map.keys() |> Enum.sort()\n    [\n      :abstract_code,\n      :atoms,\n      :attributes,\n      :compile_info,\n      :debug_info,\n      :docs,\n      :elixir_checker,\n      :exports,\n      :imports,\n      :indexed_imports,\n      :labeled_exports,\n      :labeled_locals,\n      :locals\n    ]\n    iex> Map.get(chunks, :docs)\n    {:docs_v1, 1, :elixir, \"text/markdown\", :none, %{},\n     [{{:function, :hello, 0}, 2, [\"hello()\"], :none, %{}}]}\n\n    iex> {:ok, chunks} = BeamFile.all_chunks(BeamFile.Example, :ids)\n    iex> chunks |> Map.keys() |> Enum.sort()\n    ['Abst', 'AtU8', 'Attr', 'CInf', 'Dbgi', 'Docs', 'ExCk', 'ExpT', 'ImpT', 'LocT']\n    iex> chunks |> Map.get('Docs') |> is_binary()\n    true","ref":"BeamFile.html#all_chunks/2-examples"},{"type":"function","title":"BeamFile.all_chunks!/2","doc":"Same as `all_chunks/` but raises `BeamFile.Error`","ref":"BeamFile.html#all_chunks!/2"},{"type":"function","title":"BeamFile.binary/1","doc":"Returns the `binary` for the given input.","ref":"BeamFile.html#binary/1"},{"type":"function","title":"BeamFile.binary!/1","doc":"Same as `binary/1` but raises `BeamFile.Error`","ref":"BeamFile.html#binary!/1"},{"type":"function","title":"BeamFile.byte_code/1","doc":"Returns the byte code for the BEAM file.","ref":"BeamFile.html#byte_code/1"},{"type":"function","title":"Examples - BeamFile.byte_code/1","doc":"iex> {:ok, byte_code} = BeamFile.byte_code(BeamFile.Example)\n    iex> byte_code |> Tuple.to_list() |> Enum.take(3)\n    [\n      :beam_file,\n      BeamFile.Example,\n      [{:__info__, 1, 2}, {:hello, 0, 11}, {:module_info, 0, 13}, {:module_info, 1, 15}]\n    ]","ref":"BeamFile.html#byte_code/1-examples"},{"type":"function","title":"BeamFile.byte_code!/1","doc":"Same as `byte_code/1` but raises `BeamFile.Error`","ref":"BeamFile.html#byte_code!/1"},{"type":"function","title":"BeamFile.chunk/2","doc":"Returns infos for the given chunk reference.","ref":"BeamFile.html#chunk/2"},{"type":"function","title":"Examples - BeamFile.chunk/2","doc":"iex> BeamFile.chunk(BeamFile.Example, :exports)\n    {:ok, [__info__: 1, hello: 0, module_info: 0, module_info: 1]}\n\n    iex> {:ok, chunk} = BeamFile.chunk(BeamFile.Example, 'Dbgi')\n    iex> is_binary(chunk)\n    true","ref":"BeamFile.html#chunk/2-examples"},{"type":"function","title":"BeamFile.chunk!/2","doc":"Same as `chunk/2` but raises `BeamFile.Error`","ref":"BeamFile.html#chunk!/2"},{"type":"function","title":"BeamFile.debug_info/1","doc":"Returns the infos from the  `:debug_info` chunk.\n\nExamples:\n\n    iex> {:ok, info} = BeamFile.debug_info(BeamFile.Example)\n    iex> info |> Map.get(:definitions) |> hd() |> elem(0)\n    {:hello, 0}\n    iex> Map.get(info, :relative_file)\n    \"test/fixtures/example.ex\"","ref":"BeamFile.html#debug_info/1"},{"type":"function","title":"BeamFile.debug_info!/1","doc":"Same as `debug_info/1` but raises `BeamFile.Error`","ref":"BeamFile.html#debug_info!/1"},{"type":"function","title":"BeamFile.docs/2","doc":"Returns the infos from the `:docs` chunk.","ref":"BeamFile.html#docs/2"},{"type":"function","title":"Options - BeamFile.docs/2","doc":"* `format` - the output format. The format `:info` reduces the output to the\n    type and the infos `:since`, `:hidden` and `:deprecated`. The format `since`\n    reduces the output to the type and the info `:since`.\n\n  * `hidden` - indicates whether only hidden or none hidden items are returned.\n    Without the option hidden and none hidden items are returned.\n\n  * `deprecated` - indicates wheter only deprecated or none deprecated items are\n    returned. Without the option deprecated and none deprecated items are returned.\n\n  * `since` - expected a version requirement. With `since`, the function returns\n    all items whose since attribute matches `since`. When `since` does not match\n    the module attribute since and not any item in the module matches, the tuple\n    `{:ok, nil}` is returned.","ref":"BeamFile.html#docs/2-options"},{"type":"function","title":"Examples - BeamFile.docs/2","doc":"iex> BeamFile.docs(BeamFile.Example)\n    {:ok, {:none, %{}, [{{:function, :hello, 0}, 2, [\"hello()\"], :none, %{}}]}}\n\nExamples with options (Elixir 1.16):\n```elixir\niex> BeamFile.docs(Float, format: :info, deprecated: true)\n{:ok,\n {[\n    {{:function, :to_char_list, 1}, [since: nil, hidden: true, deprecated: true]},\n    {{:function, :to_char_list, 2}, [since: nil, hidden: true, deprecated: true]},\n    {{:function, :to_string, 2}, [since: nil, hidden: true, deprecated: true]}\n  ], [since: nil, hidden: false, deprecated: false]}}\n\niex> BeamFile.docs(Date, format: :since, since: \"~> 1.12\")\n{:ok,\n {[\n    {{:function, :after?, 2}, [since: \"1.15.0\"]},\n    {{:function, :before?, 2}, [since: \"1.15.0\"]},\n    {{:function, :range, 3}, [since: \"1.12.0\"]}\n  ], [since: nil]}}\n```","ref":"BeamFile.html#docs/2-examples"},{"type":"function","title":"BeamFile.docs!/2","doc":"Same as `docs/2` but raises `BeamFile.Error`","ref":"BeamFile.html#docs!/2"},{"type":"function","title":"BeamFile.elixir_code/2","doc":"Returns elixir code recreated from the `debug_info` chunk.\n\nThe recreated code comes with resolved macros and references.\nFor now, types and specs will not be recreated.\n\nOptions:\n`:docs`: With `docs: true` the docs will be created.","ref":"BeamFile.html#elixir_code/2"},{"type":"function","title":"Examples - BeamFile.elixir_code/2","doc":"iex> BeamFile.elixir_code(BeamFile.Example)\n    {\n      :ok,\n      \"\"\"\n      defmodule Elixir.BeamFile.Example do\n        def hello do\n          :world\n        end\n      end\\\n      \"\"\"\n    }","ref":"BeamFile.html#elixir_code/2-examples"},{"type":"function","title":"BeamFile.elixir_code!/2","doc":"Same as `elixir_code/1` but raises `BeamFile.Error`","ref":"BeamFile.html#elixir_code!/2"},{"type":"function","title":"BeamFile.elixir_quoted/1","doc":"Returns the extended Elixir AST.","ref":"BeamFile.html#elixir_quoted/1"},{"type":"function","title":"BeamFile.elixir_quoted!/1","doc":"Same as `elixir_quoted/1` but raises `BeamFile.Error`","ref":"BeamFile.html#elixir_quoted!/1"},{"type":"function","title":"BeamFile.erl_code/1","doc":"Returns the Erlang code for the BEAM file.","ref":"BeamFile.html#erl_code/1"},{"type":"function","title":"Examples - BeamFile.erl_code/1","doc":"iex> {:ok, code} = BeamFile.erl_code(BeamFile.Example)\n    iex> code =~ \"-module('Elixir.BeamFile.Example')\"\n    true","ref":"BeamFile.html#erl_code/1-examples"},{"type":"function","title":"BeamFile.erl_code!/1","doc":"Same as `erl_code/1` but raises `BeamFile.Error`","ref":"BeamFile.html#erl_code!/1"},{"type":"function","title":"BeamFile.exists?/1","doc":"Returns `true` if a BEAM file for the given `module` exists.","ref":"BeamFile.html#exists?/1"},{"type":"function","title":"Examples - BeamFile.exists?/1","doc":"iex> BeamFile.exists?(BeamFile.Example)\n    true\n    iex> BeamFile.exists?(Physics.TOE)\n    false","ref":"BeamFile.html#exists?/1-examples"},{"type":"function","title":"BeamFile.info/1","doc":"Returns a keyword list containing some information about a BEAM file.\n\n- `:file`: The name of the BEAM file, or the binary from which the information\n  was extracted.\n- `:module`: The name of the module.\n- `:chunks`: For each chunk, the identifier and the position and size of the\n  chunk data, in bytes.","ref":"BeamFile.html#info/1"},{"type":"function","title":"Examples - BeamFile.info/1","doc":"iex> {:ok, info} = BeamFile.info(BeamFile.Example)\n    iex> info[:module]\n    BeamFile.Example\n    iex> info[:chunks]\n    ...> |> Enum.map(fn {id, _pos, _size} -> id end)\n    ...> |> Enum.sort()\n    [\n      'AtU8',\n      'Attr',\n      'CInf',\n      'Code',\n      'Dbgi',\n      'Docs',\n      'ExCk',\n      'ExpT',\n      'ImpT',\n      'Line',\n      'LitT',\n      'LocT',\n      'StrT',\n      'Type'\n    ]","ref":"BeamFile.html#info/1-examples"},{"type":"function","title":"BeamFile.which/1","doc":"Returns the absolute filename for the `module`.\n\nIf the module cannot be found, `{:error, :non_existing}` is returned.\n\nIf the module is preloaded, `{:error, :preloaded}` is returned.\n\nIf the module is Cover-compiled, `{:error, :cover_compiled}` is returned.","ref":"BeamFile.html#which/1"},{"type":"function","title":"Examples - BeamFile.which/1","doc":"iex> {:ok, path} = BeamFile.which(BeamFile.Example)\n    iex> path =~ \"/_build/test/lib/beam_file/ebin/Elixir.BeamFile.Example.beam\"","ref":"BeamFile.html#which/1-examples"},{"type":"function","title":"BeamFile.which!/1","doc":"Same as `which/1` but raises `BeamFile.Error`","ref":"BeamFile.html#which!/1"},{"type":"type","title":"BeamFile.beam/0","doc":"","ref":"BeamFile.html#t:beam/0"},{"type":"type","title":"BeamFile.chunk_id/0","doc":"Chunk ID.\n\n```\n'Abst'\n| 'Attr'\n| 'AtU8'\n| 'CInf'\n| 'Dbgi'\n| 'Dcos'\n| 'ExCk'\n| 'ExpT'\n| 'ImpT'\n| 'LocT'\n```","ref":"BeamFile.html#t:chunk_id/0"},{"type":"type","title":"BeamFile.chunk_name/0","doc":"","ref":"BeamFile.html#t:chunk_name/0"},{"type":"type","title":"BeamFile.chunk_ref/0","doc":"","ref":"BeamFile.html#t:chunk_ref/0"},{"type":"type","title":"BeamFile.info/0","doc":"","ref":"BeamFile.html#t:info/0"},{"type":"type","title":"BeamFile.input/0","doc":"","ref":"BeamFile.html#t:input/0"},{"type":"type","title":"BeamFile.path/0","doc":"","ref":"BeamFile.html#t:path/0"},{"type":"type","title":"BeamFile.reason/0","doc":"","ref":"BeamFile.html#t:reason/0"},{"type":"task","title":"mix beam.file","doc":"Prints the decompiled source for a module.\n\n```shell\nmix beam.file module switch\n```\nThe argument `module` specifies the `module` to decompile. The `switch` can be\none of `--elixir`, `--erlang`, or `--bytte-code`.\n\nDecompiling with `--elixir` returns the expanded Elixir code.","ref":"Mix.Tasks.Beam.File.html"},{"type":"exception","title":"BeamFile.Error","doc":"","ref":"BeamFile.Error.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}